@@ -23,9 +23,10 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
     impute_missingness_with_x_j_bar_for_lm = TRUE,
     mem_cache_for_speed = TRUE,
 	serialize = FALSE,
+	seed = NULL,
     verbose = TRUE){
  
-    bart_machine = build_bart_machine(X, y, Xy, 
+    build_bart_machine(X, y, Xy, 
 	    num_trees, #
 	    num_burn_in, 
 	    num_iterations_after_burn_in, 
@@ -40,19 +41,18 @@ bartMachine = function(X = NULL, y = NULL, Xy = NULL,
 	    run_in_sample,
 	    s_sq_y,
 	    #print_tree_illustrations = FALSE
-	    cov_prior_vec = NULL,
+	    cov_prior_vec,
 	    use_missing_data,
 	    covariates_to_permute, 
-	    num_rand_samps_in_library , 
+	    num_rand_samps_in_library, 
 	    use_missing_data_dummies_as_covars,
 	    replace_missing_data_with_x_j_bar,
 	    impute_missingness_with_rf_impute,
 	    impute_missingness_with_x_j_bar_for_lm,
 	    mem_cache_for_speed,
 		serialize,
+		seed,
 	    verbose)
-
-    bart_machine
 }
 
 
@@ -62,19 +62,9 @@ bartMachineCV = function(X = NULL, y = NULL, Xy = NULL,
    nu_q_cvs = list(c(3, 0.9), c(3, 0.99), c(10, 0.75)),
    k_folds = 5, verbose = FALSE, ...){
   
-  build_bart_machine_cv(X, y, Xy, 
-   num_tree_cvs,
-   k_cvs,
-   nu_q_cvs ,
-   k_folds, ...)
-}
-
-unserialize_bart_machine_if_necessary = function(bart_machine){
-	if (is.jnull(bart_machine$java_bart_machine)){
-		stop("The bartMachine object")
-	}
-	
-	if (is.jnull(bart_machine$java_bart_machine)){
-		stop("The bartMachine object")
-	}
+  	build_bart_machine_cv(X, y, Xy, 
+	   num_tree_cvs,
+	   k_cvs,
+	   nu_q_cvs ,
+	   k_folds, ...)
 }
